==> igniteui-react-core-16.16.1.tgz: package/esm2015/lib/WebInputDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { WebInputBaseDescription } from "./WebInputBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebInputDescription = /*@__PURE__*/ (() => {
    class WebInputDescription extends WebInputBaseDescription {
        constructor() {
            super();
            this.au = null;
            this.ao = null;
            this.ap = null;
            this.aq = null;
            this.at = null;
            this.ad = false;
            this.ah = 0;
            this.ag = 0;
            this.as = null;
            this.ar = null;
            this.ai = 0;
            this.ac = false;
            this.am = null;
            this.an = null;
        }
        get_type() {
            return "WebInput";
        }
        get value() {
            return this.au;
        }
        set value(a) {
            this.au = a;
            this.e("Value");
        }
        get dir() {
            return this.ao;
        }
        set dir(a) {
            this.ao = a;
            this.e("Dir");
        }
        get displayType() {
            return this.ap;
        }
        set displayType(a) {
            this.ap = a;
            this.e("DisplayType");
        }
        get inputmode() {
            return this.aq;
        }
        set inputmode(a) {
            this.aq = a;
            this.e("Inputmode");
        }
        get pattern() {
            return this.at;
        }
        set pattern(a) {
            this.at = a;
            this.e("Pattern");
        }
        get invalid() {
            return this.ad;
        }
        set invalid(a) {
            this.ad = a;
            this.e("Invalid");
        }
        get minlength() {
            return this.ah;
        }
        set minlength(a) {
            this.ah = a;
            this.e("Minlength");
        }
        get maxlength() {
            return this.ag;
        }
        set maxlength(a) {
            this.ag = a;
            this.e("Maxlength");
        }
        get min() {
            return this.as;
        }
        set min(a) {
            this.as = a;
            this.e("Min");
        }
        get max() {
            return this.ar;
        }
        set max(a) {
            this.ar = a;
            this.e("Max");
        }
        get step() {
            return this.ai;
        }
        set step(a) {
            this.ai = a;
            this.e("Step");
        }
        get autofocus() {
            return this.ac;
        }
        set autofocus(a) {
            this.ac = a;
            this.e("Autofocus");
        }
        get autocomplete() {
            return this.am;
        }
        set autocomplete(a) {
            this.am = a;
            this.e("Autocomplete");
        }
        get changeRef() {
            return this.an;
        }
        set changeRef(a) {
            this.an = a;
            this.e("ChangeRef");
        }
    }
    WebInputDescription.$t = /*@__PURE__*/ markType(WebInputDescription, 'WebInputDescription', WebInputBaseDescription.$);
    return WebInputDescription;
})();

==> igniteui-react-core-19.0.0.tgz: package/esm2015/lib/WebInputDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { WebInputBaseDescription } from "./WebInputBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebInputDescription = /*@__PURE__*/ (() => {
    class WebInputDescription extends WebInputBaseDescription {
        get_type() {
            return "WebInput";
        }
        constructor() {
            super();
            this.az = null;
            this.aw = null;
            this.ax = null;
            this.ay = null;
            this.an = 0;
            this.al = 0;
            this.am = 0;
            this.ak = 0;
            this.ao = 0;
            this.ag = false;
            this.au = null;
            this.ah = false;
            this.av = null;
        }
        get value() {
            return this.az;
        }
        set value(a) {
            this.az = a;
            this.g("Value");
        }
        get displayType() {
            return this.aw;
        }
        set displayType(a) {
            this.aw = a;
            this.g("DisplayType");
        }
        get inputMode() {
            return this.ax;
        }
        set inputMode(a) {
            this.ax = a;
            this.g("InputMode");
        }
        get pattern() {
            return this.ay;
        }
        set pattern(a) {
            this.ay = a;
            this.g("Pattern");
        }
        get minLength() {
            return this.an;
        }
        set minLength(a) {
            this.an = a;
            this.g("MinLength");
        }
        get maxLength() {
            return this.al;
        }
        set maxLength(a) {
            this.al = a;
            this.g("MaxLength");
        }
        get min() {
            return this.am;
        }
        set min(a) {
            this.am = a;
            this.g("Min");
        }
        get max() {
            return this.ak;
        }
        set max(a) {
            this.ak = a;
            this.g("Max");
        }
        get step() {
            return this.ao;
        }
        set step(a) {
            this.ao = a;
            this.g("Step");
        }
        get autofocus() {
            return this.ag;
        }
        set autofocus(a) {
            this.ag = a;
            this.g("Autofocus");
        }
        get autocomplete() {
            return this.au;
        }
        set autocomplete(a) {
            this.au = a;
            this.g("Autocomplete");
        }
        get validateOnly() {
            return this.ah;
        }
        set validateOnly(a) {
            this.ah = a;
            this.g("ValidateOnly");
        }
        get changeRef() {
            return this.av;
        }
        set changeRef(a) {
            this.av = a;
            this.g("ChangeRef");
        }
    }
    WebInputDescription.$t = /*@__PURE__*/ markType(WebInputDescription, 'WebInputDescription', WebInputBaseDescription.$);
    return WebInputDescription;
})();
